# Contributing

Welcome to `aag-weather` contributor's guide.

Please see the main [POCS contributing guidelines](https://github.com/panoptes/POCS/blob/2eb3586d9ceb95039aec7be993d90fd4dbc4afa5/CONTRIBUTING.rst) for general information about contributing to this project.
